@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import os
-import sys
 from textwrap import dedent
 from typing import TYPE_CHECKING
 from unittest import mock
@@ -13,10 +12,8 @@ from requests import Session
 
 import semantic_release.hvcs.github
 from semantic_release.changelog.context import ChangelogMode
-from semantic_release.cli.commands.main import main
 from semantic_release.cli.config import ChangelogOutputFormat
 from semantic_release.hvcs.github import Github
-from semantic_release.version.version import Version
 
 from tests.const import (
     CHANGELOG_SUBCMD,
@@ -36,31 +33,31 @@ from tests.fixtures.example_project import (
     example_changelog_rst,
 )
 from tests.fixtures.repos import (
-    repo_w_git_flow_angular_commits,
+    repo_w_git_flow_conventional_commits,
     repo_w_git_flow_emoji_commits,
     repo_w_git_flow_scipy_commits,
-    repo_w_git_flow_w_alpha_prereleases_n_angular_commits,
+    repo_w_git_flow_w_alpha_prereleases_n_conventional_commits,
     repo_w_git_flow_w_alpha_prereleases_n_emoji_commits,
     repo_w_git_flow_w_alpha_prereleases_n_scipy_commits,
-    repo_w_git_flow_w_beta_alpha_rev_prereleases_n_angular_commits,
+    repo_w_git_flow_w_beta_alpha_rev_prereleases_n_conventional_commits,
     repo_w_git_flow_w_beta_alpha_rev_prereleases_n_emoji_commits,
     repo_w_git_flow_w_beta_alpha_rev_prereleases_n_scipy_commits,
-    repo_w_git_flow_w_rc_n_alpha_prereleases_n_angular_commits,
-    repo_w_git_flow_w_rc_n_alpha_prereleases_n_angular_commits_using_tag_format,
+    repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits,
+    repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits_using_tag_format,
     repo_w_git_flow_w_rc_n_alpha_prereleases_n_emoji_commits,
     repo_w_git_flow_w_rc_n_alpha_prereleases_n_scipy_commits,
-    repo_w_github_flow_w_default_release_channel_angular_commits,
+    repo_w_github_flow_w_default_release_channel_conventional_commits,
     repo_w_github_flow_w_default_release_channel_emoji_commits,
     repo_w_github_flow_w_default_release_channel_scipy_commits,
-    repo_w_github_flow_w_feature_release_channel_angular_commits,
+    repo_w_github_flow_w_feature_release_channel_conventional_commits,
     repo_w_github_flow_w_feature_release_channel_emoji_commits,
     repo_w_github_flow_w_feature_release_channel_scipy_commits,
-    repo_w_no_tags_angular_commits,
+    repo_w_no_tags_conventional_commits,
     repo_w_no_tags_emoji_commits,
     repo_w_no_tags_scipy_commits,
-    repo_w_trunk_only_angular_commits,
+    repo_w_trunk_only_conventional_commits,
     repo_w_trunk_only_emoji_commits,
-    repo_w_trunk_only_n_prereleases_angular_commits,
+    repo_w_trunk_only_n_prereleases_conventional_commits,
     repo_w_trunk_only_n_prereleases_emoji_commits,
     repo_w_trunk_only_n_prereleases_scipy_commits,
     repo_w_trunk_only_scipy_commits,
@@ -77,9 +74,15 @@ if TYPE_CHECKING:
     from pathlib import Path
     from typing import TypedDict
 
-    from click.testing import CliRunner
     from requests_mock import Mocker
 
+    from semantic_release.commit_parser.conventional import (
+        ConventionalCommitParser,
+    )
+    from semantic_release.commit_parser.emoji import EmojiCommitParser
+    from semantic_release.commit_parser.scipy import ScipyCommitParser
+
+    from tests.conftest import RunCliFn
     from tests.e2e.conftest import RetrieveRuntimeContextFn
     from tests.fixtures.example_project import (
         ExProjectDir,
@@ -98,7 +101,7 @@ if TYPE_CHECKING:
     )
 
     class Commit2Section(TypedDict):
-        angular: Commit2SectionCommit
+        conventional: Commit2SectionCommit
         emoji: Commit2SectionCommit
         scipy: Commit2SectionCommit
 
@@ -115,15 +118,15 @@ if TYPE_CHECKING:
         for repo_fixture in (
             # Only need to test when it has tags or no tags
             # DO NOT need to consider all repo types as it doesn't change no-op behavior
-            repo_w_no_tags_angular_commits.__name__,
-            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_no_tags_conventional_commits.__name__,
+            repo_w_trunk_only_conventional_commits.__name__,
         )
     ],
 )
 def test_changelog_noop_is_noop(
     repo_result: BuiltRepoResult,
     arg0: str | None,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
 ):
     repo = repo_result["repo"]
@@ -152,7 +155,7 @@ def test_changelog_noop_is_noop(
     ), requests_mock.Mocker(session=session) as mocker:
         args = [arg0, f"v{version_str}"] if version_str and arg0 else []
         cli_cmd = [MAIN_PROG_NAME, "--noop", CHANGELOG_SUBCMD, *args]
-        result = cli_runner.invoke(main, cli_cmd[1:])
+        result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -184,8 +187,8 @@ def test_changelog_noop_is_noop(
             lazy_fixture(repo_fixture)
             for repo_fixture in [
                 # All commit types and one without a release
-                repo_w_no_tags_angular_commits.__name__,
-                repo_w_trunk_only_angular_commits.__name__,
+                repo_w_no_tags_conventional_commits.__name__,
+                repo_w_trunk_only_conventional_commits.__name__,
                 repo_w_trunk_only_emoji_commits.__name__,
                 repo_w_trunk_only_scipy_commits.__name__,
             ]
@@ -193,41 +196,41 @@ def test_changelog_noop_is_noop(
         *[
             pytest.param(lazy_fixture(repo_fixture), marks=pytest.mark.comprehensive)
             for repo_fixture in [
-                # repo_w_no_tags_angular_commits.__name__,
+                # repo_w_no_tags_conventional_commits.__name__,
                 repo_w_no_tags_emoji_commits.__name__,
                 repo_w_no_tags_scipy_commits.__name__,
-                # repo_w_trunk_only_angular_commits.__name__,
+                # repo_w_trunk_only_conventional_commits.__name__,
                 # repo_w_trunk_only_emoji_commits.__name__,
                 # repo_w_trunk_only_scipy_commits.__name__,
-                repo_w_trunk_only_n_prereleases_angular_commits.__name__,
+                repo_w_trunk_only_n_prereleases_conventional_commits.__name__,
                 repo_w_trunk_only_n_prereleases_emoji_commits.__name__,
                 repo_w_trunk_only_n_prereleases_scipy_commits.__name__,
-                repo_w_github_flow_w_default_release_channel_angular_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_conventional_commits.__name__,
                 repo_w_github_flow_w_default_release_channel_emoji_commits.__name__,
                 repo_w_github_flow_w_default_release_channel_scipy_commits.__name__,
-                repo_w_github_flow_w_feature_release_channel_angular_commits.__name__,
+                repo_w_github_flow_w_feature_release_channel_conventional_commits.__name__,
                 repo_w_github_flow_w_feature_release_channel_emoji_commits.__name__,
                 repo_w_github_flow_w_feature_release_channel_scipy_commits.__name__,
-                repo_w_git_flow_angular_commits.__name__,
+                repo_w_git_flow_conventional_commits.__name__,
                 repo_w_git_flow_emoji_commits.__name__,
                 repo_w_git_flow_scipy_commits.__name__,
-                repo_w_git_flow_w_beta_alpha_rev_prereleases_n_angular_commits.__name__,
+                repo_w_git_flow_w_beta_alpha_rev_prereleases_n_conventional_commits.__name__,
                 repo_w_git_flow_w_beta_alpha_rev_prereleases_n_emoji_commits.__name__,
                 repo_w_git_flow_w_beta_alpha_rev_prereleases_n_scipy_commits.__name__,
-                repo_w_git_flow_w_alpha_prereleases_n_angular_commits.__name__,
+                repo_w_git_flow_w_alpha_prereleases_n_conventional_commits.__name__,
                 repo_w_git_flow_w_alpha_prereleases_n_emoji_commits.__name__,
                 repo_w_git_flow_w_alpha_prereleases_n_scipy_commits.__name__,
-                repo_w_git_flow_w_rc_n_alpha_prereleases_n_angular_commits.__name__,
+                repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits.__name__,
                 repo_w_git_flow_w_rc_n_alpha_prereleases_n_emoji_commits.__name__,
                 repo_w_git_flow_w_rc_n_alpha_prereleases_n_scipy_commits.__name__,
-                repo_w_git_flow_w_rc_n_alpha_prereleases_n_angular_commits_using_tag_format.__name__,
+                repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits_using_tag_format.__name__,
             ]
         ],
     ],
 )
 def test_changelog_content_regenerated(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     changelog_file: Path,
     insertion_flag: str,
@@ -255,7 +258,7 @@ def test_changelog_content_regenerated(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -289,12 +292,12 @@ def test_changelog_content_regenerated_masked_initial_release(
     build_repo_from_definition: BuildRepoFromDefinitionFn,
     get_repo_definition_4_trunk_only_repo_w_tags: GetRepoDefinitionFn,
     example_project_dir: ExProjectDir,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     changelog_file: Path,
     insertion_flag: str,
 ):
     build_definition = get_repo_definition_4_trunk_only_repo_w_tags(
-        commit_type="angular",
+        commit_type="conventional",
         mask_initial_release=True,
         extra_configs={
             "tool.semantic_release.changelog.default_templates.changelog_file": str(
@@ -319,7 +322,7 @@ def test_changelog_content_regenerated_masked_initial_release(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -345,7 +348,7 @@ def test_changelog_content_regenerated_masked_initial_release(
     [
         lazy_fixture(repo_fixture)
         for repo_fixture in [
-            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_conventional_commits.__name__,
             repo_w_trunk_only_emoji_commits.__name__,
             repo_w_trunk_only_scipy_commits.__name__,
         ]
@@ -353,7 +356,7 @@ def test_changelog_content_regenerated_masked_initial_release(
 )
 def test_changelog_update_mode_unchanged(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     changelog_file: Path,
 ):
@@ -376,7 +379,7 @@ def test_changelog_update_mode_unchanged(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -402,10 +405,10 @@ def test_changelog_update_mode_unchanged(
     [
         lazy_fixture(repo_fixture)
         for repo_fixture in [
-            repo_w_no_tags_angular_commits.__name__,
+            repo_w_no_tags_conventional_commits.__name__,
             repo_w_no_tags_emoji_commits.__name__,
             repo_w_no_tags_scipy_commits.__name__,
-            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_conventional_commits.__name__,
             repo_w_trunk_only_emoji_commits.__name__,
             repo_w_trunk_only_scipy_commits.__name__,
         ]
@@ -413,7 +416,7 @@ def test_changelog_update_mode_unchanged(
 )
 def test_changelog_update_mode_no_prev_changelog(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     changelog_file: Path,
 ):
@@ -439,7 +442,7 @@ def test_changelog_update_mode_no_prev_changelog(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -473,7 +476,7 @@ def test_changelog_update_mode_no_prev_changelog(
     [
         lazy_fixture(repo_fixture)
         for repo_fixture in [
-            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_conventional_commits.__name__,
             repo_w_trunk_only_emoji_commits.__name__,
             repo_w_trunk_only_scipy_commits.__name__,
         ]
@@ -481,7 +484,7 @@ def test_changelog_update_mode_no_prev_changelog(
 )
 def test_changelog_update_mode_no_flag(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     changelog_file: Path,
     insertion_flag: str,
@@ -514,7 +517,7 @@ def test_changelog_update_mode_no_flag(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -547,7 +550,7 @@ def test_changelog_update_mode_no_flag(
         lazy_fixture(repo_fixture)
         for repo_fixture in [
             # MUST HAVE at least 2 tags!
-            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_conventional_commits.__name__,
             repo_w_trunk_only_emoji_commits.__name__,
             repo_w_trunk_only_scipy_commits.__name__,
         ]
@@ -555,7 +558,7 @@ def test_changelog_update_mode_no_flag(
 )
 def test_changelog_update_mode_no_header(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     changelog_format: ChangelogOutputFormat,
     changelog_file: Path,
@@ -613,7 +616,7 @@ def test_changelog_update_mode_no_header(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -649,7 +652,7 @@ def test_changelog_update_mode_no_header(
         lazy_fixture(repo_fixture)
         for repo_fixture in [
             # MUST HAVE at least 2 tags!
-            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_conventional_commits.__name__,
             repo_w_trunk_only_emoji_commits.__name__,
             repo_w_trunk_only_scipy_commits.__name__,
         ]
@@ -657,7 +660,7 @@ def test_changelog_update_mode_no_header(
 )
 def test_changelog_update_mode_no_footer(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     changelog_format: ChangelogOutputFormat,
     changelog_file: Path,
@@ -717,7 +720,7 @@ def test_changelog_update_mode_no_footer(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -753,7 +756,7 @@ def test_changelog_update_mode_no_footer(
         lazy_fixture(repo_fixture)
         for repo_fixture in [
             # Must not have a single release/tag
-            repo_w_no_tags_angular_commits.__name__,
+            repo_w_no_tags_conventional_commits.__name__,
             repo_w_no_tags_emoji_commits.__name__,
             repo_w_no_tags_scipy_commits.__name__,
         ]
@@ -761,7 +764,7 @@ def test_changelog_update_mode_no_footer(
 )
 def test_changelog_update_mode_no_releases(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     changelog_file: Path,
     insertion_flag: str,
@@ -816,7 +819,7 @@ def test_changelog_update_mode_no_releases(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -852,7 +855,7 @@ def test_changelog_update_mode_no_releases(
     [
         (lazy_fixture(repo_fixture), repo_fixture.split("_")[-2])
         for repo_fixture in [
-            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_conventional_commits.__name__,
             repo_w_trunk_only_emoji_commits.__name__,
             repo_w_trunk_only_scipy_commits.__name__,
         ]
@@ -862,16 +865,19 @@ def test_changelog_update_mode_unreleased_n_released(
     repo_result: BuiltRepoResult,
     commit_type: CommitConvention,
     changelog_format: ChangelogOutputFormat,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     example_git_ssh_url: str,
     file_in_repo: str,
     commit_n_rtn_changelog_entry: CommitNReturnChangelogEntryFn,
     changelog_file: Path,
     insertion_flag: str,
-    get_commit_def_of_angular_commit: GetCommitDefFn,
-    get_commit_def_of_emoji_commit: GetCommitDefFn,
-    get_commit_def_of_scipy_commit: GetCommitDefFn,
+    get_commit_def_of_conventional_commit: GetCommitDefFn[ConventionalCommitParser],
+    get_commit_def_of_emoji_commit: GetCommitDefFn[EmojiCommitParser],
+    get_commit_def_of_scipy_commit: GetCommitDefFn[ScipyCommitParser],
+    default_conventional_parser: ConventionalCommitParser,
+    default_emoji_parser: EmojiCommitParser,
+    default_scipy_parser: ScipyCommitParser,
 ):
     """
     Given there are unreleased changes and a previous release in the changelog,
@@ -890,20 +896,25 @@ def test_changelog_update_mode_unreleased_n_released(
     )
 
     commit_n_section: Commit2Section = {
-        "angular": {
-            "commit": get_commit_def_of_angular_commit(
-                "perf: improve the performance of the application"
+        "conventional": {
+            "commit": get_commit_def_of_conventional_commit(
+                "perf: improve the performance of the application",
+                parser=default_conventional_parser,
             ),
             "section": "Performance Improvements",
         },
         "emoji": {
             "commit": get_commit_def_of_emoji_commit(
-                ":zap: improve the performance of the application"
+                ":zap: improve the performance of the application",
+                parser=default_emoji_parser,
             ),
             "section": ":zap:",
         },
         "scipy": {
-            "commit": get_commit_def_of_scipy_commit("MAINT: fix an issue"),
+            "commit": get_commit_def_of_scipy_commit(
+                "MAINT: fix an issue",
+                parser=default_scipy_parser,
+            ),
             "section": "Fix",
         },
     }
@@ -933,7 +944,10 @@ def test_changelog_update_mode_unreleased_n_released(
         repo,
         commit_n_section[commit_type]["commit"],
     )
-    hvcs = Github(example_git_ssh_url, hvcs_domain=EXAMPLE_HVCS_DOMAIN)
+
+    with mock.patch.dict(os.environ, {}, clear=True):
+        hvcs = Github(example_git_ssh_url, hvcs_domain=EXAMPLE_HVCS_DOMAIN)
+        assert hvcs.repo_name  # force caching of repo values (ignoring the env)
 
     unreleased_change_variants = {
         ChangelogOutputFormat.MARKDOWN: dedent(
@@ -992,7 +1006,7 @@ def test_changelog_update_mode_unreleased_n_released(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -1009,24 +1023,24 @@ def test_changelog_update_mode_unreleased_n_released(
 
 
 # Just need to test that it works for "a" project, not all
-@pytest.mark.usefixtures(repo_w_trunk_only_n_prereleases_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_n_prereleases_conventional_commits.__name__)
 @pytest.mark.parametrize(
     "args", [("--post-to-release-tag", "v1.99.91910000000000000000000000000")]
 )
 def test_changelog_release_tag_not_in_history(
     args: list[str],
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
 ):
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD, *args]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_exit_code(2, result, cli_cmd)
     assert "not in release history" in result.stderr.lower()
 
 
-@pytest.mark.usefixtures(repo_w_trunk_only_n_prereleases_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_n_prereleases_conventional_commits.__name__)
 @pytest.mark.parametrize(
     "args",
     [
@@ -1035,7 +1049,7 @@ def test_changelog_release_tag_not_in_history(
         ("--post-to-release-tag", "v0.2.0"),  #      latest release
     ],
 )
-def test_changelog_post_to_release(args: list[str], cli_runner: CliRunner):
+def test_changelog_post_to_release(args: list[str], run_cli: RunCliFn):
     # Set up a requests HTTP session so we can catch the HTTP calls and ensure they're
     # made
 
@@ -1055,59 +1069,22 @@ def test_changelog_post_to_release(args: list[str], cli_runner: CliRunner):
         repo_name=EXAMPLE_REPO_NAME,
     )
 
-    clean_os_environment = dict(
-        filter(
-            lambda k_v: k_v[1] is not None,
-            {
-                "CI": "true",
-                "PATH": os.getenv("PATH"),
-                "HOME": os.getenv("HOME"),
-                "VIRTUAL_ENV": os.getenv("VIRTUAL_ENV", "./.venv"),
-                **(
-                    {}
-                    if sys.platform != "win32"
-                    else {
-                        # Windows Required variables
-                        "ALLUSERSAPPDATA": os.getenv("ALLUSERSAPPDATA"),
-                        "ALLUSERSPROFILE": os.getenv("ALLUSERSPROFILE"),
-                        "APPDATA": os.getenv("APPDATA"),
-                        "COMMONPROGRAMFILES": os.getenv("COMMONPROGRAMFILES"),
-                        "COMMONPROGRAMFILES(X86)": os.getenv("COMMONPROGRAMFILES(X86)"),
-                        "DEFAULTUSERPROFILE": os.getenv("DEFAULTUSERPROFILE"),
-                        "HOMEPATH": os.getenv("HOMEPATH"),
-                        "PATHEXT": os.getenv("PATHEXT"),
-                        "PROFILESFOLDER": os.getenv("PROFILESFOLDER"),
-                        "PROGRAMFILES": os.getenv("PROGRAMFILES"),
-                        "PROGRAMFILES(X86)": os.getenv("PROGRAMFILES(X86)"),
-                        "SYSTEM": os.getenv("SYSTEM"),
-                        "SYSTEM16": os.getenv("SYSTEM16"),
-                        "SYSTEM32": os.getenv("SYSTEM32"),
-                        "SYSTEMDRIVE": os.getenv("SYSTEMDRIVE"),
-                        "SYSTEMROOT": os.getenv("SYSTEMROOT"),
-                        "TEMP": os.getenv("TEMP"),
-                        "TMP": os.getenv("TMP"),
-                        "USERPROFILE": os.getenv("USERPROFILE"),
-                        "USERSID": os.getenv("USERSID"),
-                        "USERNAME": os.getenv("USERNAME"),
-                        "WINDIR": os.getenv("WINDIR"),
-                    }
-                ),
-            }.items(),
-        )
-    )
-
     # Patch out env vars that affect changelog URLs but only get set in e.g.
     # Github actions
     with mock.patch(
         # Patching the specific module's reference to the build_requests_session function
         f"{semantic_release.hvcs.github.__name__}.{semantic_release.hvcs.github.build_requests_session.__name__}",
         return_value=session,
-    ) as build_requests_session_mock, mock.patch.dict(
-        os.environ, clean_os_environment, clear=True
-    ):
+    ) as build_requests_session_mock:
         # Act
         cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD, *args]
-        result = cli_runner.invoke(main, cli_cmd[1:])
+        result = run_cli(
+            cli_cmd[1:],
+            env={
+                "CI": "true",
+                "VIRTUAL_ENV": os.getenv("VIRTUAL_ENV", "./.venv"),
+            },
+        )
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -1119,7 +1096,7 @@ def test_changelog_post_to_release(args: list[str], cli_runner: CliRunner):
 
 @pytest.mark.parametrize(
     "repo_result",
-    [lazy_fixture(repo_w_trunk_only_n_prereleases_angular_commits.__name__)],
+    [lazy_fixture(repo_w_trunk_only_n_prereleases_conventional_commits.__name__)],
 )
 def test_custom_release_notes_template(
     repo_result: BuiltRepoResult,
@@ -1127,13 +1104,11 @@ def test_custom_release_notes_template(
     use_release_notes_template: UseReleaseNotesTemplateFn,
     retrieve_runtime_context: RetrieveRuntimeContextFn,
     post_mocker: Mocker,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
 ) -> None:
     """Verify the template `.release_notes.md.j2` from `template_dir` is used."""
     expected_call_count = 1
-    version = Version.parse(
-        get_versions_from_repo_build_def(repo_result["definition"])[-1]
-    )
+    version = get_versions_from_repo_build_def(repo_result["definition"])[-1]
 
     # Setup
     use_release_notes_template()
@@ -1157,7 +1132,7 @@ def test_custom_release_notes_template(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD, "--post-to-release-tag", tag]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Assert
     assert_successful_exit_code(result, cli_cmd)
@@ -1168,13 +1143,13 @@ def test_custom_release_notes_template(
     assert expected_release_notes == actual_notes
 
 
-@pytest.mark.usefixtures(repo_w_trunk_only_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_conventional_commits.__name__)
 def test_changelog_default_on_empty_template_dir(
     example_changelog_md: Path,
     changelog_template_dir: Path,
     example_project_template_dir: Path,
     update_pyproject_toml: UpdatePyprojectTomlFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
 ):
     # Setup: Make sure default changelog doesn't already exist
     example_changelog_md.unlink(missing_ok=True)
@@ -1190,7 +1165,7 @@ def test_changelog_default_on_empty_template_dir(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -1199,13 +1174,13 @@ def test_changelog_default_on_empty_template_dir(
     assert example_changelog_md.exists()
 
 
-@pytest.mark.usefixtures(repo_w_trunk_only_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_conventional_commits.__name__)
 def test_changelog_default_on_incorrect_config_template_file(
     example_changelog_md: Path,
     changelog_template_dir: Path,
     example_project_template_dir: Path,
     update_pyproject_toml: UpdatePyprojectTomlFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
 ):
     # Setup: Make sure default changelog doesn't already exist
     example_changelog_md.unlink(missing_ok=True)
@@ -1222,7 +1197,7 @@ def test_changelog_default_on_incorrect_config_template_file(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
@@ -1232,11 +1207,11 @@ def test_changelog_default_on_incorrect_config_template_file(
 
 
 @pytest.mark.parametrize("bad_changelog_file_str", ("/etc/passwd", "../../.ssh/id_rsa"))
-@pytest.mark.usefixtures(repo_w_trunk_only_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_conventional_commits.__name__)
 def test_changelog_prevent_malicious_path_traversal_file(
     update_pyproject_toml: UpdatePyprojectTomlFn,
     bad_changelog_file_str: str,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
 ):
     # Setup: A malicious path traversal filepath outside of the repository
     update_pyproject_toml(
@@ -1246,7 +1221,7 @@ def test_changelog_prevent_malicious_path_traversal_file(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, "--noop", CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_exit_code(1, result, cli_cmd)
@@ -1257,11 +1232,11 @@ def test_changelog_prevent_malicious_path_traversal_file(
 
 
 @pytest.mark.parametrize("template_dir_path", ("~/.ssh", "../../.ssh"))
-@pytest.mark.usefixtures(repo_w_trunk_only_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_conventional_commits.__name__)
 def test_changelog_prevent_external_path_traversal_dir(
     update_pyproject_toml: UpdatePyprojectTomlFn,
     template_dir_path: str,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
 ):
     # Setup: A malicious path traversal filepath outside of the repository
     update_pyproject_toml(
@@ -1271,7 +1246,7 @@ def test_changelog_prevent_external_path_traversal_dir(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, "--noop", CHANGELOG_SUBCMD]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # Evaluate
     assert_exit_code(1, result, cli_cmd)
