@@ -3,7 +3,8 @@ from __future__ import annotations
 import os
 from pathlib import Path
 from textwrap import dedent
-from typing import TYPE_CHECKING, Generator
+from typing import TYPE_CHECKING, Generator, cast
+from unittest import mock
 
 import pytest
 import tomlkit
@@ -12,8 +13,14 @@ import tomlkit
 from importlib_resources import files
 
 import semantic_release
+from semantic_release.cli.config import (
+    GlobalCommandLineOptions,
+    RawConfig,
+    RuntimeContext,
+)
+from semantic_release.cli.util import load_raw_config_file
 from semantic_release.commit_parser import (
-    AngularCommitParser,
+    ConventionalCommitParser,
     EmojiCommitParser,
     ScipyCommitParser,
 )
@@ -37,7 +44,11 @@ from tests.util import copy_dir_tree, temporary_working_directory
 if TYPE_CHECKING:
     from typing import Any, Protocol, Sequence
 
+    from tomlkit.container import Container as TOMLContainer
+
     from semantic_release.commit_parser import CommitParser
+    from semantic_release.commit_parser._base import ParserOptions
+    from semantic_release.commit_parser.token import ParseResult
     from semantic_release.hvcs import HvcsBase
     from semantic_release.version.version import Version
 
@@ -50,28 +61,68 @@ if TYPE_CHECKING:
     ExProjectDir = Path
 
     class GetWheelFileFn(Protocol):
-        def __call__(self, version_str: str) -> Path: ...
+        def __call__(self, version_str: str, pkg_name: str = ...) -> Path: ...
 
     class SetFlagFn(Protocol):
-        def __call__(self, flag: bool) -> None: ...
+        def __call__(self, flag: bool, toml_file: Path | str = ...) -> None: ...
 
     class UpdatePyprojectTomlFn(Protocol):
-        def __call__(self, setting: str, value: Any) -> None: ...
+        def __call__(
+            self, setting: str, value: Any, toml_file: Path | str = ...
+        ) -> None: ...
 
     class UseCustomParserFn(Protocol):
-        def __call__(self, module_import_str: str) -> None: ...
+        def __call__(
+            self, module_import_str: str, toml_file: Path | str = ...
+        ) -> None: ...
 
     class UseHvcsFn(Protocol):
-        def __call__(self, domain: str | None = None) -> type[HvcsBase]: ...
+        def __call__(
+            self, domain: str | None = None, toml_file: Path | str = ...
+        ) -> type[HvcsBase]: ...
 
     class UseParserFn(Protocol):
-        def __call__(self) -> type[CommitParser]: ...
+        def __call__(
+            self, toml_file: Path | str = ...
+        ) -> type[CommitParser[ParseResult, ParserOptions]]: ...
 
     class UseReleaseNotesTemplateFn(Protocol):
-        def __call__(self) -> None: ...
+        def __call__(self, toml_file: Path | str = ...) -> None: ...
 
     class UpdateVersionPyFileFn(Protocol):
-        def __call__(self, version: Version | str) -> None: ...
+        def __call__(
+            self, version: Version | str, version_file: Path | str = ...
+        ) -> None: ...
+
+    class GetHvcsFn(Protocol):
+        def __call__(
+            self,
+            hvcs_client_name: str,
+            origin_url: str = ...,
+            hvcs_domain: str | None = None,
+        ) -> Github | Gitlab | Gitea | Bitbucket: ...
+
+    class ReadConfigFileFn(Protocol):
+        """Read the raw config file from `config_path`."""
+
+        def __call__(self, file: Path | str = ...) -> RawConfig: ...
+
+    class LoadRuntimeContextFn(Protocol):
+        """Load the runtime context from the config file."""
+
+        def __call__(
+            self, cli_opts: GlobalCommandLineOptions | None = None
+        ) -> RuntimeContext: ...
+
+    class GetParserFromConfigFileFn(Protocol):
+        """Get the commit parser from the config file."""
+
+        def __call__(
+            self, file: Path | str = ...
+        ) -> CommitParser[ParseResult, ParserOptions]: ...
+
+    class GetExpectedVersionPyFileContentFn(Protocol):
+        def __call__(self, version: Version | str) -> str: ...
 
 
 @pytest.fixture(scope="session")
@@ -248,7 +299,7 @@ def default_changelog_md_template() -> Path:
     return Path(
         str(
             files(semantic_release.__name__).joinpath(
-                Path("data", "templates", "angular", "md", "CHANGELOG.md.j2")
+                Path("data", "templates", "conventional", "md", "CHANGELOG.md.j2")
             )
         )
     ).resolve()
@@ -260,7 +311,7 @@ def default_changelog_rst_template() -> Path:
     return Path(
         str(
             files(semantic_release.__name__).joinpath(
-                Path("data", "templates", "angular", "rst", "CHANGELOG.rst.j2")
+                Path("data", "templates", "conventional", "rst", "CHANGELOG.rst.j2")
             )
         )
     ).resolve()
@@ -268,12 +319,58 @@ def default_changelog_rst_template() -> Path:
 
 @pytest.fixture(scope="session")
 def get_wheel_file(dist_dir: Path) -> GetWheelFileFn:
-    def _get_wheel_file(version_str: str) -> Path:
-        return dist_dir / f"{EXAMPLE_PROJECT_NAME}-{version_str}-py3-none-any.whl"
+    def _get_wheel_file(
+        version_str: str,
+        pkg_name: str = EXAMPLE_PROJECT_NAME,
+    ) -> Path:
+        return dist_dir.joinpath(
+            f"{pkg_name.replace('-', '_')}-{version_str}-py3-none-any.whl"
+        )
 
     return _get_wheel_file
 
 
+@pytest.fixture(scope="session")
+def read_config_file(pyproject_toml_file: Path) -> ReadConfigFileFn:
+    def _read_config_file(file: Path | str = pyproject_toml_file) -> RawConfig:
+        config_text = load_raw_config_file(file)
+        return RawConfig.model_validate(config_text)
+
+    return _read_config_file
+
+
+@pytest.fixture(scope="session")
+def load_runtime_context(
+    read_config_file: ReadConfigFileFn,
+    pyproject_toml_file: Path,
+) -> LoadRuntimeContextFn:
+    def _load_runtime_context(
+        cli_opts: GlobalCommandLineOptions | None = None,
+    ) -> RuntimeContext:
+        opts = cli_opts or GlobalCommandLineOptions(
+            config_file=str(pyproject_toml_file),
+        )
+        raw_config = read_config_file(opts.config_file)
+        return RuntimeContext.from_raw_config(raw_config, opts)
+
+    return _load_runtime_context
+
+
+@pytest.fixture(scope="session")
+def get_parser_from_config_file(
+    pyproject_toml_file: Path,
+    load_runtime_context: LoadRuntimeContextFn,
+) -> GetParserFromConfigFileFn:
+    def _get_parser_from_config(
+        file: Path | str = pyproject_toml_file,
+    ) -> CommitParser[ParseResult, ParserOptions]:
+        return load_runtime_context(
+            cli_opts=GlobalCommandLineOptions(config_file=str(Path(file)))
+        ).commit_parser
+
+    return _get_parser_from_config
+
+
 @pytest.fixture
 def example_project_dir(tmp_path: Path) -> ExProjectDir:
     return tmp_path.resolve()
@@ -300,11 +397,15 @@ def use_release_notes_template(
     example_project_template_dir: Path,
     changelog_template_dir: Path,
     update_pyproject_toml: UpdatePyprojectTomlFn,
+    pyproject_toml_file: Path,
 ) -> UseReleaseNotesTemplateFn:
-    def _use_release_notes_template() -> None:
+    def _use_release_notes_template(
+        toml_file: Path | str = pyproject_toml_file,
+    ) -> None:
         update_pyproject_toml(
             "tool.semantic_release.changelog.template_dir",
             str(changelog_template_dir),
+            toml_file=toml_file,
         )
         example_project_template_dir.mkdir(parents=True, exist_ok=True)
         release_notes_j2 = example_project_template_dir / ".release_notes.md.j2"
@@ -380,18 +481,39 @@ def example_project_template_dir(
 
 
 @pytest.fixture(scope="session")
-def update_version_py_file(version_py_file: Path) -> UpdateVersionPyFileFn:
-    def _update_version_py_file(version: Version | str) -> None:
-        cwd_version_py = version_py_file.resolve()
-        cwd_version_py.parent.mkdir(parents=True, exist_ok=True)
-        cwd_version_py.write_text(
-            dedent(
-                f"""\
-                __version__ = "{version}"
-                """
-            )
+def get_expected_version_py_file_content() -> GetExpectedVersionPyFileContentFn:
+    def _get_expected_version_py_file_content(version: Version | str) -> str:
+        return dedent(
+            f"""\
+            __version__ = "{version}"
+            """
         )
 
+    return _get_expected_version_py_file_content
+
+
+@pytest.fixture(scope="session")
+def update_version_py_file(
+    version_py_file: Path,
+    get_expected_version_py_file_content: GetExpectedVersionPyFileContentFn,
+) -> UpdateVersionPyFileFn:
+    """
+    Updates the specified file with the expected version string content
+
+    :param version: The version to set in the file
+    :type version: Version | str
+
+    :param version_file: The file to update
+    :type version_file: Path | str
+    """
+
+    def _update_version_py_file(
+        version: Version | str, version_file: Path | str = version_py_file
+    ) -> None:
+        cwd_version_py = Path(version_file).resolve()
+        cwd_version_py.parent.mkdir(parents=True, exist_ok=True)
+        cwd_version_py.write_text(get_expected_version_py_file_content(version))
+
     return _update_version_py_file
 
 
@@ -399,8 +521,10 @@ def update_version_py_file(version_py_file: Path) -> UpdateVersionPyFileFn:
 def update_pyproject_toml(pyproject_toml_file: Path) -> UpdatePyprojectTomlFn:
     """Update the pyproject.toml file with the given content."""
 
-    def _update_pyproject_toml(setting: str, value: Any) -> None:
-        cwd_pyproject_toml = pyproject_toml_file.resolve()
+    def _update_pyproject_toml(
+        setting: str, value: Any, toml_file: Path | str = pyproject_toml_file
+    ) -> None:
+        cwd_pyproject_toml = Path(toml_file).resolve()
         with open(cwd_pyproject_toml) as rfd:
             pyproject_toml = tomlkit.load(rfd)
 
@@ -409,11 +533,13 @@ def update_pyproject_toml(pyproject_toml_file: Path) -> UpdatePyprojectTomlFn:
         new_setting_key = parts.pop(-1)
         new_setting[new_setting_key] = value
 
-        pointer = pyproject_toml
+        pointer: TOMLContainer = pyproject_toml
         for part in parts:
-            if pointer.get(part, None) is None:
-                pointer.add(part, tomlkit.table())
-            pointer = pointer.get(part, {})
+            if (next_pointer := pointer.get(part, None)) is None:
+                next_pointer = tomlkit.table()
+                pointer.add(part, next_pointer)
+
+            pointer = cast("TOMLContainer", next_pointer)
 
         if value is None:
             pointer.pop(new_setting_key)
@@ -432,127 +558,257 @@ def pyproject_toml_config_option_parser() -> str:
 
 
 @pytest.fixture(scope="session")
-def set_major_on_zero(update_pyproject_toml: UpdatePyprojectTomlFn) -> SetFlagFn:
+def pyproject_toml_config_option_remote_type() -> str:
+    return f"tool.{semantic_release.__name__}.remote.type"
+
+
+@pytest.fixture(scope="session")
+def pyproject_toml_config_option_remote_domain() -> str:
+    return f"tool.{semantic_release.__name__}.remote.domain"
+
+
+@pytest.fixture(scope="session")
+def set_major_on_zero(
+    pyproject_toml_file: Path, update_pyproject_toml: UpdatePyprojectTomlFn
+) -> SetFlagFn:
     """Turn on/off the major_on_zero setting."""
 
-    def _set_major_on_zero(flag: bool) -> None:
-        update_pyproject_toml("tool.semantic_release.major_on_zero", flag)
+    def _set_major_on_zero(
+        flag: bool, toml_file: Path | str = pyproject_toml_file
+    ) -> None:
+        update_pyproject_toml("tool.semantic_release.major_on_zero", flag, toml_file)
 
     return _set_major_on_zero
 
 
 @pytest.fixture(scope="session")
-def set_allow_zero_version(update_pyproject_toml: UpdatePyprojectTomlFn) -> SetFlagFn:
+def set_allow_zero_version(
+    pyproject_toml_file: Path, update_pyproject_toml: UpdatePyprojectTomlFn
+) -> SetFlagFn:
     """Turn on/off the allow_zero_version setting."""
 
-    def _set_allow_zero_version(flag: bool) -> None:
-        update_pyproject_toml("tool.semantic_release.allow_zero_version", flag)
+    def _set_allow_zero_version(
+        flag: bool, toml_file: Path | str = pyproject_toml_file
+    ) -> None:
+        update_pyproject_toml(
+            "tool.semantic_release.allow_zero_version", flag, toml_file
+        )
 
     return _set_allow_zero_version
 
 
 @pytest.fixture(scope="session")
-def use_angular_parser(
+def use_conventional_parser(
+    pyproject_toml_file: Path,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     pyproject_toml_config_option_parser: str,
 ) -> UseParserFn:
-    """Modify the configuration file to use the Angular parser."""
+    """Modify the configuration file to use the Conventional parser."""
 
-    def _use_angular_parser() -> type[CommitParser]:
-        update_pyproject_toml(pyproject_toml_config_option_parser, "angular")
-        return AngularCommitParser
+    def _use_conventional_parser(
+        toml_file: Path | str = pyproject_toml_file,
+    ) -> type[CommitParser[ParseResult, ParserOptions]]:
+        update_pyproject_toml(
+            pyproject_toml_config_option_parser, "conventional", toml_file=toml_file
+        )
+        return cast(
+            "type[CommitParser[ParseResult, ParserOptions]]", ConventionalCommitParser
+        )
 
-    return _use_angular_parser
+    return _use_conventional_parser
 
 
 @pytest.fixture(scope="session")
 def use_emoji_parser(
+    pyproject_toml_file: Path,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     pyproject_toml_config_option_parser: str,
 ) -> UseParserFn:
     """Modify the configuration file to use the Emoji parser."""
 
-    def _use_emoji_parser() -> type[CommitParser]:
-        update_pyproject_toml(pyproject_toml_config_option_parser, "emoji")
-        return EmojiCommitParser
+    def _use_emoji_parser(
+        toml_file: Path | str = pyproject_toml_file,
+    ) -> type[CommitParser[ParseResult, ParserOptions]]:
+        update_pyproject_toml(
+            pyproject_toml_config_option_parser, "emoji", toml_file=toml_file
+        )
+        return cast("type[CommitParser[ParseResult, ParserOptions]]", EmojiCommitParser)
 
     return _use_emoji_parser
 
 
 @pytest.fixture(scope="session")
 def use_scipy_parser(
+    pyproject_toml_file: Path,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     pyproject_toml_config_option_parser: str,
 ) -> UseParserFn:
     """Modify the configuration file to use the Scipy parser."""
 
-    def _use_scipy_parser() -> type[CommitParser]:
-        update_pyproject_toml(pyproject_toml_config_option_parser, "scipy")
-        return ScipyCommitParser
+    def _use_scipy_parser(
+        toml_file: Path | str = pyproject_toml_file,
+    ) -> type[CommitParser[ParseResult, ParserOptions]]:
+        update_pyproject_toml(
+            pyproject_toml_config_option_parser, "scipy", toml_file=toml_file
+        )
+        return cast("type[CommitParser[ParseResult, ParserOptions]]", ScipyCommitParser)
 
     return _use_scipy_parser
 
 
 @pytest.fixture(scope="session")
 def use_custom_parser(
+    pyproject_toml_file: Path,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     pyproject_toml_config_option_parser: str,
 ) -> UseCustomParserFn:
     """Modify the configuration file to use a user defined string parser."""
 
-    def _use_custom_parser(module_import_str: str) -> None:
-        update_pyproject_toml(pyproject_toml_config_option_parser, module_import_str)
+    def _use_custom_parser(
+        module_import_str: str, toml_file: Path | str = pyproject_toml_file
+    ) -> None:
+        update_pyproject_toml(
+            pyproject_toml_config_option_parser, module_import_str, toml_file=toml_file
+        )
 
     return _use_custom_parser
 
 
 @pytest.fixture(scope="session")
-def use_github_hvcs(update_pyproject_toml: UpdatePyprojectTomlFn) -> UseHvcsFn:
+def get_hvcs(example_git_https_url: str) -> GetHvcsFn:
+    hvcs_clients: dict[str, type[HvcsBase]] = {
+        "github": Github,
+        "gitlab": Gitlab,
+        "gitea": Gitea,
+        "bitbucket": Bitbucket,
+    }
+
+    def _get_hvcs(
+        hvcs_client_name: str,
+        origin_url: str = example_git_https_url,
+        hvcs_domain: str | None = None,
+    ) -> Github | Gitlab | Gitea | Bitbucket:
+        if (hvcs_class := hvcs_clients.get(hvcs_client_name)) is None:
+            raise ValueError(f"Unknown HVCS client name: {hvcs_client_name}")
+
+        # Create HVCS Client instance
+        with mock.patch.dict(os.environ, {}, clear=True):
+            hvcs = hvcs_class(origin_url, hvcs_domain=hvcs_domain)
+            assert hvcs.repo_name  # Force the HVCS client to cache the repo name
+            assert hvcs.owner  # Force the HVCS client to cache the owner
+
+        return cast("Github | Gitlab | Gitea | Bitbucket", hvcs)
+
+    return _get_hvcs
+
+
+@pytest.fixture(scope="session")
+def use_github_hvcs(
+    pyproject_toml_file: Path,
+    update_pyproject_toml: UpdatePyprojectTomlFn,
+    pyproject_toml_config_option_remote_type: str,
+    pyproject_toml_config_option_remote_domain: str,
+) -> UseHvcsFn:
     """Modify the configuration file to use GitHub as the HVCS."""
 
-    def _use_github_hvcs(domain: str | None = None) -> type[HvcsBase]:
-        update_pyproject_toml("tool.semantic_release.remote.type", "github")
+    def _use_github_hvcs(
+        domain: str | None = None, toml_file: Path | str = pyproject_toml_file
+    ) -> type[HvcsBase]:
+        update_pyproject_toml(
+            pyproject_toml_config_option_remote_type,
+            Github.__name__.lower(),
+            toml_file=toml_file,
+        )
+
         if domain is not None:
-            update_pyproject_toml("tool.semantic_release.remote.domain", domain)
+            update_pyproject_toml(
+                pyproject_toml_config_option_remote_domain, domain, toml_file=toml_file
+            )
+
         return Github
 
     return _use_github_hvcs
 
 
 @pytest.fixture(scope="session")
-def use_gitlab_hvcs(update_pyproject_toml: UpdatePyprojectTomlFn) -> UseHvcsFn:
+def use_gitlab_hvcs(
+    pyproject_toml_file: Path,
+    update_pyproject_toml: UpdatePyprojectTomlFn,
+    pyproject_toml_config_option_remote_type: str,
+    pyproject_toml_config_option_remote_domain: str,
+) -> UseHvcsFn:
     """Modify the configuration file to use GitLab as the HVCS."""
 
-    def _use_gitlab_hvcs(domain: str | None = None) -> type[HvcsBase]:
-        update_pyproject_toml("tool.semantic_release.remote.type", "gitlab")
+    def _use_gitlab_hvcs(
+        domain: str | None = None, toml_file: Path | str = pyproject_toml_file
+    ) -> type[HvcsBase]:
+        update_pyproject_toml(
+            pyproject_toml_config_option_remote_type,
+            Gitlab.__name__.lower(),
+            toml_file=toml_file,
+        )
+
         if domain is not None:
-            update_pyproject_toml("tool.semantic_release.remote.domain", domain)
+            update_pyproject_toml(
+                pyproject_toml_config_option_remote_domain, domain, toml_file=toml_file
+            )
+
         return Gitlab
 
     return _use_gitlab_hvcs
 
 
 @pytest.fixture(scope="session")
-def use_gitea_hvcs(update_pyproject_toml: UpdatePyprojectTomlFn) -> UseHvcsFn:
+def use_gitea_hvcs(
+    pyproject_toml_file: Path,
+    update_pyproject_toml: UpdatePyprojectTomlFn,
+    pyproject_toml_config_option_remote_type: str,
+    pyproject_toml_config_option_remote_domain: str,
+) -> UseHvcsFn:
     """Modify the configuration file to use Gitea as the HVCS."""
 
-    def _use_gitea_hvcs(domain: str | None = None) -> type[HvcsBase]:
-        update_pyproject_toml("tool.semantic_release.remote.type", "gitea")
+    def _use_gitea_hvcs(
+        domain: str | None = None, toml_file: Path | str = pyproject_toml_file
+    ) -> type[HvcsBase]:
+        update_pyproject_toml(
+            pyproject_toml_config_option_remote_type,
+            Gitea.__name__.lower(),
+            toml_file=toml_file,
+        )
+
         if domain is not None:
-            update_pyproject_toml("tool.semantic_release.remote.domain", domain)
+            update_pyproject_toml(
+                pyproject_toml_config_option_remote_domain, domain, toml_file=toml_file
+            )
+
         return Gitea
 
     return _use_gitea_hvcs
 
 
 @pytest.fixture(scope="session")
-def use_bitbucket_hvcs(update_pyproject_toml: UpdatePyprojectTomlFn) -> UseHvcsFn:
+def use_bitbucket_hvcs(
+    pyproject_toml_file: Path,
+    update_pyproject_toml: UpdatePyprojectTomlFn,
+    pyproject_toml_config_option_remote_type: str,
+    pyproject_toml_config_option_remote_domain: str,
+) -> UseHvcsFn:
     """Modify the configuration file to use BitBucket as the HVCS."""
 
-    def _use_bitbucket_hvcs(domain: str | None = None) -> type[HvcsBase]:
-        update_pyproject_toml("tool.semantic_release.remote.type", "bitbucket")
+    def _use_bitbucket_hvcs(
+        domain: str | None = None, toml_file: Path | str = pyproject_toml_file
+    ) -> type[HvcsBase]:
+        update_pyproject_toml(
+            pyproject_toml_config_option_remote_type,
+            Bitbucket.__name__.lower(),
+            toml_file=toml_file,
+        )
+
         if domain is not None:
-            update_pyproject_toml("tool.semantic_release.remote.domain", domain)
+            update_pyproject_toml(
+                pyproject_toml_config_option_remote_domain, domain, toml_file=toml_file
+            )
+
         return Bitbucket
 
     return _use_bitbucket_hvcs
