@@ -3,11 +3,12 @@ from __future__ import annotations
 from datetime import timedelta
 from itertools import count
 from pathlib import Path
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
 import pytest
 
 from semantic_release.cli.config import ChangelogOutputFormat
+from semantic_release.version.version import Version
 
 import tests.conftest
 import tests.const
@@ -20,7 +21,15 @@ from tests.const import (
 )
 
 if TYPE_CHECKING:
-    from typing import Sequence
+    from typing import Any, Sequence
+
+    from semantic_release.commit_parser._base import CommitParser, ParserOptions
+    from semantic_release.commit_parser.conventional import (
+        ConventionalCommitParser,
+    )
+    from semantic_release.commit_parser.emoji import EmojiCommitParser
+    from semantic_release.commit_parser.scipy import ScipyCommitParser
+    from semantic_release.commit_parser.token import ParseResult
 
     from tests.conftest import (
         GetCachedRepoDataFn,
@@ -85,19 +94,29 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
     changelog_md_file: Path,
     changelog_rst_file: Path,
     stable_now_date: GetStableDateNowFn,
+    default_conventional_parser: ConventionalCommitParser,
+    default_emoji_parser: EmojiCommitParser,
+    default_scipy_parser: ScipyCommitParser,
+    default_tag_format_str: str,
 ) -> GetRepoDefinitionFn:
     """
     Builds a repository with the GitHub Flow branching strategy and a squash commit merging strategy
     for a single release channel on the default branch.
     """
+    parser_classes: dict[CommitConvention, CommitParser[Any, Any]] = {
+        "conventional": default_conventional_parser,
+        "emoji": default_emoji_parser,
+        "scipy": default_scipy_parser,
+    }
 
-    def _get_repo_from_defintion(
+    def _get_repo_from_definition(
         commit_type: CommitConvention,
         hvcs_client_name: str = "github",
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
-        mask_initial_release: bool = False,
+        mask_initial_release: bool = True,
+        ignore_merge_commits: bool = True,
     ) -> Sequence[RepoActions]:
         stable_now_datetime = stable_now_date()
         commit_timestamp_gen = (
@@ -105,15 +124,21 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
             for i in count(step=1)
         )
         pr_num_gen = (i for i in count(start=2, step=1))
+        commit_parser = cast(
+            "CommitParser[ParseResult, ParserOptions]",
+            parser_classes[commit_type],
+        )
 
-        changelog_file_definitons: Sequence[RepoActionWriteChangelogsDestFile] = [
+        changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
+                "mask_initial_release": mask_initial_release,
             },
             {
                 "path": changelog_rst_file,
                 "format": ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                "mask_initial_release": mask_initial_release,
             },
         ]
 
@@ -126,7 +151,7 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                     "commit_type": commit_type,
                     "hvcs_client_name": hvcs_client_name,
                     "hvcs_domain": hvcs_domain,
-                    "tag_format_str": tag_format_str,
+                    "tag_format_str": tag_format_str or default_tag_format_str,
                     "mask_initial_release": mask_initial_release,
                     "extra_configs": {
                         # Set the default release branch
@@ -136,13 +161,16 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                         },
                         "tool.semantic_release.allow_zero_version": False,
                         "tool.semantic_release.commit_parser_options.parse_squash_commits": True,
+                        "tool.semantic_release.commit_parser_options.ignore_merge_commits": ignore_merge_commits,
                         **(extra_configs or {}),
                     },
                 },
             }
         )
 
-        new_version = "1.0.0"
+        new_version = Version.parse(
+            "1.0.0", tag_format=(tag_format_str or default_tag_format_str)
+        )
 
         repo_construction_steps.extend(
             [
@@ -152,7 +180,10 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "angular": INITIAL_COMMIT_MESSAGE,
+                                    "cid": (
+                                        cid_db_c1_initial := "db_c1_initial_commit"
+                                    ),
+                                    "conventional": INITIAL_COMMIT_MESSAGE,
                                     "emoji": INITIAL_COMMIT_MESSAGE,
                                     "scipy": INITIAL_COMMIT_MESSAGE,
                                     "datetime": next(commit_timestamp_gen),
@@ -161,7 +192,8 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                                     ),
                                 },
                                 {
-                                    "angular": "feat: add new feature",
+                                    "cid": (cid_db_c2_feat := "db_c2_feat"),
+                                    "conventional": "feat: add new feature",
                                     "emoji": ":sparkles: add new feature",
                                     "scipy": "ENH: add new feature",
                                     "datetime": next(commit_timestamp_gen),
@@ -169,20 +201,23 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_db_c1_initial, cid_db_c2_feat],
                                 },
                             },
                         ],
@@ -193,9 +228,10 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
 
         fix_branch_1_commits: Sequence[CommitSpec] = [
             {
-                "angular": "fix(cli): add missing text",
-                "emoji": ":bug: add missing text",
-                "scipy": "MAINT: add missing text",
+                "cid": "fix_branch_c1",
+                "conventional": "fix(cli): add missing text\n\nResolves: #123\n",
+                "emoji": ":bug: add missing text\n\nResolves: #123\n",
+                "scipy": "MAINT: add missing text\n\nResolves: #123\n",
                 "datetime": next(commit_timestamp_gen),
             },
         ]
@@ -223,6 +259,7 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                                 for commit in fix_branch_1_commits
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
@@ -232,19 +269,22 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
         # simulate separate work by another person at same time as the fix branch
         feat_branch_1_commits: Sequence[CommitSpec] = [
             {
-                "angular": "feat(cli): add cli interface",
+                "cid": "feat_branch_c1",
+                "conventional": "feat(cli): add cli interface",
                 "emoji": ":sparkles: add cli interface",
                 "scipy": "ENH: add cli interface",
                 "datetime": next(commit_timestamp_gen),
             },
             {
-                "angular": "test(cli): add cli tests",
+                "cid": "feat_branch_c2",
+                "conventional": "test(cli): add cli tests",
                 "emoji": ":checkmark: add cli tests",
                 "scipy": "TST: add cli tests",
                 "datetime": next(commit_timestamp_gen),
             },
             {
-                "angular": "docs(cli): add cli documentation",
+                "cid": "feat_branch_c3",
+                "conventional": "docs(cli): add cli documentation",
                 "emoji": ":memo: add cli documentation",
                 "scipy": "DOC: add cli documentation",
                 "datetime": next(commit_timestamp_gen),
@@ -274,16 +314,21 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                                 for commit in feat_branch_1_commits
                             ],
                             commit_type,
+                            parser=commit_parser,
                         )
                     },
                 },
             ]
         )
 
-        new_version = "1.0.1"
+        new_version = Version.parse("1.0.1", tag_format=new_version.tag_format)
 
-        all_commit_types: list[CommitConvention] = ["angular", "emoji", "scipy"]
+        all_commit_types: list[CommitConvention] = ["conventional", "emoji", "scipy"]
         fix_branch_pr_number = next(pr_num_gen)
+        cid_fix_branch_squash_base = "fix_branch_1_squash"
+        cid_fix_branch_squash_gen = (
+            f"{cid_fix_branch_squash_base}-{i}" for i in count(start=1)
+        )
         fix_branch_squash_commit_spec: CommitSpec = {
             **{  # type: ignore[typeddict-item]
                 cmt_type: format_squash_commit_msg_github(
@@ -291,10 +336,13 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                     pr_title=fix_branch_1_commits[0][cmt_type],
                     pr_number=fix_branch_pr_number,
                     # No squashed commits since there is only one commit
-                    squashed_commits=[],
+                    squashed_commits=[
+                        cmt[commit_type] for cmt in fix_branch_1_commits[1:]
+                    ],
                 )
                 for cmt_type in all_commit_types
             },
+            "cid": cid_fix_branch_squash_base,
             "datetime": next(commit_timestamp_gen),
             "include_in_changelog": True,
         }
@@ -313,20 +361,26 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                         "commit_def": convert_commit_spec_to_commit_def(
                             fix_branch_squash_commit_spec,
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
+                                    "commit_ids": [
+                                        next(cid_fix_branch_squash_gen)
+                                        for _ in range(len(fix_branch_1_commits))
+                                    ],
                                 },
                             },
                         ],
@@ -336,6 +390,10 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
         )
 
         feat_branch_pr_number = next(pr_num_gen)
+        cid_feat_branch_squash_base = "feat_branch_1_squash"
+        cid_feat_branch_squash_gen = (
+            f"{cid_feat_branch_squash_base}-{i}" for i in count(start=1)
+        )
         feat_branch_squash_commit_spec: CommitSpec = {
             **{  # type: ignore[typeddict-item]
                 cmt_type: format_squash_commit_msg_github(
@@ -348,11 +406,12 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                 )
                 for cmt_type in all_commit_types
             },
+            "cid": cid_feat_branch_squash_base,
             "datetime": next(commit_timestamp_gen),
             "include_in_changelog": True,
         }
 
-        new_version = "1.1.0"
+        new_version = Version.parse("1.1.0", tag_format=new_version.tag_format)
 
         repo_construction_steps.extend(
             [
@@ -364,20 +423,26 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
                         "commit_def": convert_commit_spec_to_commit_def(
                             feat_branch_squash_commit_spec,
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
+                                    "commit_ids": [
+                                        next(cid_feat_branch_squash_gen)
+                                        for _ in range(len(feat_branch_1_commits) + 1)
+                                    ],
                                 },
                             },
                         ],
@@ -388,7 +453,7 @@ def get_repo_definition_4_github_flow_repo_w_default_release_channel(
 
         return repo_construction_steps
 
-    return _get_repo_from_defintion
+    return _get_repo_from_definition
 
 
 @pytest.fixture(scope="session")
@@ -431,13 +496,15 @@ def build_repo_w_github_flow_w_default_release_channel(
 
 
 @pytest.fixture
-def repo_w_github_flow_w_default_release_channel_angular_commits(
+def repo_w_github_flow_w_default_release_channel_conventional_commits(
     build_repo_w_github_flow_w_default_release_channel: BuildSpecificRepoFn,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
     change_to_ex_proj_dir: None,
 ) -> BuiltRepoResult:
-    repo_name = repo_w_github_flow_w_default_release_channel_angular_commits.__name__
+    repo_name = (
+        repo_w_github_flow_w_default_release_channel_conventional_commits.__name__
+    )
     commit_type: CommitConvention = repo_name.split("_")[-2]  # type: ignore[assignment]
 
     return {
