@@ -3,11 +3,12 @@ from __future__ import annotations
 from datetime import timedelta
 from itertools import count
 from pathlib import Path
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
 import pytest
 
 from semantic_release.cli.config import ChangelogOutputFormat
+from semantic_release.version.version import Version
 
 import tests.conftest
 import tests.const
@@ -20,7 +21,15 @@ from tests.const import (
 )
 
 if TYPE_CHECKING:
-    from typing import Sequence
+    from typing import Any, Sequence
+
+    from semantic_release.commit_parser._base import CommitParser, ParserOptions
+    from semantic_release.commit_parser.conventional import (
+        ConventionalCommitParser,
+    )
+    from semantic_release.commit_parser.emoji import EmojiCommitParser
+    from semantic_release.commit_parser.scipy import ScipyCommitParser
+    from semantic_release.commit_parser.token import ParseResult
 
     from tests.conftest import (
         GetCachedRepoDataFn,
@@ -79,11 +88,20 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
     changelog_md_file: Path,
     changelog_rst_file: Path,
     stable_now_date: GetStableDateNowFn,
+    default_conventional_parser: ConventionalCommitParser,
+    default_emoji_parser: EmojiCommitParser,
+    default_scipy_parser: ScipyCommitParser,
+    default_tag_format_str: str,
 ) -> GetRepoDefinitionFn:
     """
     Builds a repository with trunk-only committing (no-branching) strategy with
     only official releases with latest and previous version support.
     """
+    parser_classes: dict[CommitConvention, CommitParser[Any, Any]] = {
+        "conventional": default_conventional_parser,
+        "emoji": default_emoji_parser,
+        "scipy": default_scipy_parser,
+    }
 
     def _get_repo_from_definition(
         commit_type: CommitConvention,
@@ -99,15 +117,21 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
             (stable_now_datetime + timedelta(seconds=i)).isoformat(timespec="seconds")
             for i in count(step=1)
         )
+        commit_parser = cast(
+            "CommitParser[ParseResult, ParserOptions]",
+            parser_classes[commit_type],
+        )
 
         changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
+                "mask_initial_release": mask_initial_release,
             },
             {
                 "path": changelog_rst_file,
                 "format": ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                "mask_initial_release": mask_initial_release,
             },
         ]
 
@@ -120,7 +144,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                     "commit_type": commit_type,
                     "hvcs_client_name": hvcs_client_name,
                     "hvcs_domain": hvcs_domain,
-                    "tag_format_str": tag_format_str,
+                    "tag_format_str": tag_format_str or default_tag_format_str,
                     "mask_initial_release": mask_initial_release,
                     "extra_configs": {
                         # Set the default release branch
@@ -132,6 +156,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                             "match": r"^v1\.x$",
                             "prerelease": False,
                         },
+                        "tool.semantic_release.commit_parser_options.ignore_merge_commits": ignore_merge_commits,
                         "tool.semantic_release.allow_zero_version": False,
                         **(extra_configs or {}),
                     },
@@ -140,7 +165,9 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # Make initial release
-        new_version = "1.0.0"
+        new_version = Version.parse(
+            "1.0.0", tag_format=(tag_format_str or default_tag_format_str)
+        )
 
         repo_construction_steps.extend(
             [
@@ -150,6 +177,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c1_initial := "c1-initial_commit"),
                                     "conventional": INITIAL_COMMIT_MESSAGE,
                                     "emoji": INITIAL_COMMIT_MESSAGE,
                                     "scipy": INITIAL_COMMIT_MESSAGE,
@@ -159,6 +187,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                     ),
                                 },
                                 {
+                                    "cid": (cid_c2_feat := "c2-feat"),
                                     "conventional": "feat: add new feature",
                                     "emoji": ":sparkles: add new feature",
                                     "scipy": "ENH: add new feature",
@@ -167,13 +196,15 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -181,6 +212,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c1_initial, cid_c2_feat],
                                 },
                             },
                         ],
@@ -190,7 +222,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # Make a fix and officially release it
-        new_version = "1.0.1"
+        new_version = Version.parse("1.0.1", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -199,6 +231,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c3_fix := "c3-fix"),
                                     "conventional": "fix: correct some text",
                                     "emoji": ":bug: correct some text",
                                     "scipy": "MAINT: correct some text",
@@ -207,13 +240,15 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -221,6 +256,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c3_fix],
                                 },
                             },
                         ],
@@ -230,7 +266,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # Make a breaking change and officially release it
-        new_version = "2.0.0"
+        new_version = Version.parse("2.0.0", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -252,6 +288,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c4_bfeat := "c4-breaking-feat1"),
                                     "conventional": str.join(
                                         "\n\n",
                                         [
@@ -278,13 +315,15 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -292,6 +331,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "details": {
                                     "new_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c4_bfeat],
                                 },
                             },
                         ],
@@ -302,7 +342,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
 
         # Attempt to fix a critical bug in the previous version and release it as a prerelease version
         # This is based on https://github.com/python-semantic-release/python-semantic-release/issues/861
-        new_version = "1.0.2-hotfix.1"
+        new_version = Version.parse("1.0.2-hotfix.1", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -315,6 +355,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c5_v1_fix := "c5-fix2"),
                                     "conventional": "fix: correct critical bug\n\nResolves: #123\n",
                                     "emoji": ":bug: correct critical bug\n\nResolves: #123\n",
                                     "scipy": "MAINT: correct critical bug\n\nResolves: #123\n",
@@ -323,13 +364,15 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -338,6 +381,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                     "new_version": new_version,
                                     "max_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c5_v1_fix],
                                 },
                             },
                         ],
@@ -347,7 +391,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # The Hotfix didn't work, so correct it and try again
-        new_version = "1.0.2-hotfix.2"
+        new_version = Version.parse("1.0.2-hotfix.2", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -356,6 +400,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c6_v1_fix := "c6-fix3"),
                                     "conventional": "fix: resolve critical bug",
                                     "emoji": ":bug: resolve critical bug",
                                     "scipy": "MAINT: resolve critical bug",
@@ -364,13 +409,15 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -379,6 +426,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                     "new_version": new_version,
                                     "max_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c6_v1_fix],
                                 },
                             },
                         ],
@@ -388,7 +436,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # It finally was resolved so release it officially
-        new_version = "1.0.2"
+        new_version = Version.parse("1.0.2", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 # {
@@ -397,6 +445,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                 #         "commits": convert_commit_specs_to_commit_defs(
                 #             [
                 #                 {
+                #                     "cid": (cid_c7_v1_docs := "c7-docs"),
                 #                     "conventional": "docs: update documentation regarding critical bug",
                 #                     "emoji": ":books: update documentation regarding critical bug",
                 #                     "scipy": "DOC: update documentation regarding critical bug",
@@ -405,13 +454,15 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                 #                 },
                 #             ],
                 #             commit_type,
+                #             parser=commit_parser,
                 #         ),
                 #     },
                 # },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -420,6 +471,11 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                     "new_version": new_version,
                                     "max_version": new_version,
                                     "dest_files": changelog_file_definitions,
+                                    "commit_ids": [
+                                        cid_c5_v1_fix,
+                                        cid_c6_v1_fix,
+                                        # cid_c7_v1_docs,
+                                    ],
                                 },
                             },
                         ],
