@@ -3,7 +3,7 @@ from __future__ import annotations
 from datetime import timedelta
 from itertools import count
 from pathlib import Path
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
 import pytest
 
@@ -19,7 +19,15 @@ from tests.const import (
 )
 
 if TYPE_CHECKING:
-    from typing import Sequence
+    from typing import Any, Sequence
+
+    from semantic_release.commit_parser._base import CommitParser, ParserOptions
+    from semantic_release.commit_parser.conventional import (
+        ConventionalCommitParser,
+    )
+    from semantic_release.commit_parser.emoji import EmojiCommitParser
+    from semantic_release.commit_parser.scipy import ScipyCommitParser
+    from semantic_release.commit_parser.token import ParseResult
 
     from tests.conftest import (
         GetCachedRepoDataFn,
@@ -72,19 +80,28 @@ def get_repo_definition_4_trunk_only_repo_w_no_tags(
     changelog_md_file: Path,
     changelog_rst_file: Path,
     stable_now_date: GetStableDateNowFn,
+    default_conventional_parser: ConventionalCommitParser,
+    default_emoji_parser: EmojiCommitParser,
+    default_scipy_parser: ScipyCommitParser,
 ) -> GetRepoDefinitionFn:
     """
     Builds a repository with trunk-only committing (no-branching) strategy without
     any releases.
     """
+    parser_classes: dict[CommitConvention, CommitParser[Any, Any]] = {
+        "conventional": default_conventional_parser,
+        "emoji": default_emoji_parser,
+        "scipy": default_scipy_parser,
+    }
 
-    def _get_repo_from_defintion(
+    def _get_repo_from_definition(
         commit_type: CommitConvention,
         hvcs_client_name: str = "github",
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
-        mask_initial_release: bool = False,
+        mask_initial_release: bool = True,
+        ignore_merge_commits: bool = True,
     ) -> Sequence[RepoActions]:
         stable_now_datetime = stable_now_date()
         commit_timestamp_gen = (
@@ -109,6 +126,7 @@ def get_repo_definition_4_trunk_only_repo_w_no_tags(
                                 "match": r"^(main|master)$",
                                 "prerelease": False,
                             },
+                            "tool.semantic_release.commit_parser_options.ignore_merge_commits": ignore_merge_commits,
                             **(extra_configs or {}),
                         },
                     },
@@ -119,7 +137,8 @@ def get_repo_definition_4_trunk_only_repo_w_no_tags(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "angular": INITIAL_COMMIT_MESSAGE,
+                                    "cid": (cid_c1_initial := "c1_initial_commit"),
+                                    "conventional": INITIAL_COMMIT_MESSAGE,
                                     "emoji": INITIAL_COMMIT_MESSAGE,
                                     "scipy": INITIAL_COMMIT_MESSAGE,
                                     "datetime": next(commit_timestamp_gen),
@@ -128,28 +147,35 @@ def get_repo_definition_4_trunk_only_repo_w_no_tags(
                                     ),
                                 },
                                 {
-                                    "angular": "feat: add new feature",
+                                    "cid": (cid_c2_feat1 := "c2-feat1"),
+                                    "conventional": "feat: add new feature",
                                     "emoji": ":sparkles: add new feature",
                                     "scipy": "ENH: add new feature",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
                                 {
-                                    "angular": "fix: correct some text",
+                                    "cid": (cid_c3_fix1 := "c3-fix1"),
+                                    "conventional": "fix: correct some text",
                                     "emoji": ":bug: correct some text",
                                     "scipy": "MAINT: correct some text",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
                                 {
-                                    "angular": "fix: correct more text",
-                                    "emoji": ":bug: correct more text",
-                                    "scipy": "MAINT: correct more text",
+                                    "cid": (cid_c4_fix2 := "c4-fix2"),
+                                    "conventional": "fix: correct more text\n\nCloses: #123",
+                                    "emoji": ":bug: correct more text\n\nCloses: #123",
+                                    "scipy": "MAINT: correct more text\n\nCloses: #123",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
                             ],
                             commit_type,
+                            parser=cast(
+                                "CommitParser[ParseResult, ParserOptions]",
+                                parser_classes[commit_type],
+                            ),
                         ),
                     },
                 },
@@ -161,12 +187,20 @@ def get_repo_definition_4_trunk_only_repo_w_no_tags(
                             {
                                 "path": changelog_md_file,
                                 "format": ChangelogOutputFormat.MARKDOWN,
+                                "mask_initial_release": mask_initial_release,
                             },
                             {
                                 "path": changelog_rst_file,
                                 "format": ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                                "mask_initial_release": mask_initial_release,
                             },
                         ],
+                        "commit_ids": [
+                            cid_c1_initial,
+                            cid_c2_feat1,
+                            cid_c3_fix1,
+                            cid_c4_fix2,
+                        ],
                     },
                 },
             ]
@@ -174,7 +208,7 @@ def get_repo_definition_4_trunk_only_repo_w_no_tags(
 
         return repo_construction_steps
 
-    return _get_repo_from_defintion
+    return _get_repo_from_definition
 
 
 @pytest.fixture(scope="session")
@@ -215,7 +249,7 @@ def build_trunk_only_repo_w_no_tags(
 
 
 @pytest.fixture
-def repo_w_no_tags_angular_commits_using_tag_format(
+def repo_w_no_tags_conventional_commits_using_tag_format(
     build_repo_from_definition: BuildRepoFromDefinitionFn,
     get_repo_definition_4_trunk_only_repo_w_no_tags: GetRepoDefinitionFn,
     get_cached_repo_data: GetCachedRepoDataFn,
@@ -230,7 +264,7 @@ def repo_w_no_tags_angular_commits_using_tag_format(
 
     Follows tag format defined in python-semantic-release#1137
     """
-    repo_name = repo_w_no_tags_angular_commits_using_tag_format.__name__
+    repo_name = repo_w_no_tags_conventional_commits_using_tag_format.__name__
     commit_type: CommitConvention = (
         repo_name.split("_commits", maxsplit=1)[0].split("_")[-1]  # type: ignore[assignment]
     )
@@ -259,13 +293,97 @@ def repo_w_no_tags_angular_commits_using_tag_format(
 
 
 @pytest.fixture
-def repo_w_no_tags_angular_commits(
+def repo_w_no_tags_conventional_commits_w_zero_version(
+    build_repo_from_definition: BuildRepoFromDefinitionFn,
+    get_repo_definition_4_trunk_only_repo_w_no_tags: GetRepoDefinitionFn,
+    get_cached_repo_data: GetCachedRepoDataFn,
+    build_repo_or_copy_cache: BuildRepoOrCopyCacheFn,
+    build_spec_hash_4_repo_w_no_tags: str,
+    example_project_git_repo: ExProjectGitRepoFn,
+    example_project_dir: ExProjectDir,
+    change_to_ex_proj_dir: None,
+) -> BuiltRepoResult:
+    """Replicates repo with no tags, but with allow_zero_version=True"""
+    repo_name = repo_w_no_tags_conventional_commits_w_zero_version.__name__
+    commit_type: CommitConvention = (
+        repo_name.split("_commits", maxsplit=1)[0].split("_")[-1]  # type: ignore[assignment]
+    )
+
+    def _build_repo(cached_repo_path: Path) -> Sequence[RepoActions]:
+        repo_construction_steps = get_repo_definition_4_trunk_only_repo_w_no_tags(
+            commit_type=commit_type,
+            extra_configs={
+                "tool.semantic_release.allow_zero_version": True,
+            },
+        )
+        return build_repo_from_definition(cached_repo_path, repo_construction_steps)
+
+    build_repo_or_copy_cache(
+        repo_name=repo_name,
+        build_spec_hash=build_spec_hash_4_repo_w_no_tags,
+        build_repo_func=_build_repo,
+        dest_dir=example_project_dir,
+    )
+
+    if not (cached_repo_data := get_cached_repo_data(proj_dirname=repo_name)):
+        raise ValueError("Failed to retrieve repo data from cache")
+
+    return {
+        "definition": cached_repo_data["build_definition"],
+        "repo": example_project_git_repo(),
+    }
+
+
+@pytest.fixture
+def repo_w_no_tags_conventional_commits_unmasked_initial_release(
+    build_repo_from_definition: BuildRepoFromDefinitionFn,
+    get_repo_definition_4_trunk_only_repo_w_no_tags: GetRepoDefinitionFn,
+    get_cached_repo_data: GetCachedRepoDataFn,
+    build_repo_or_copy_cache: BuildRepoOrCopyCacheFn,
+    build_spec_hash_4_repo_w_no_tags: str,
+    example_project_git_repo: ExProjectGitRepoFn,
+    example_project_dir: ExProjectDir,
+    change_to_ex_proj_dir: None,
+) -> BuiltRepoResult:
+    """Replicates repo with no tags, but with mask_initial_release=False"""
+    repo_name = repo_w_no_tags_conventional_commits_unmasked_initial_release.__name__
+    commit_type: CommitConvention = (
+        repo_name.split("_commits", maxsplit=1)[0].split("_")[-1]  # type: ignore[assignment]
+    )
+
+    def _build_repo(cached_repo_path: Path) -> Sequence[RepoActions]:
+        repo_construction_steps = get_repo_definition_4_trunk_only_repo_w_no_tags(
+            commit_type=commit_type,
+            extra_configs={
+                "tool.semantic_release.changelog.default_templates.mask_initial_release": False,
+            },
+        )
+        return build_repo_from_definition(cached_repo_path, repo_construction_steps)
+
+    build_repo_or_copy_cache(
+        repo_name=repo_name,
+        build_spec_hash=build_spec_hash_4_repo_w_no_tags,
+        build_repo_func=_build_repo,
+        dest_dir=example_project_dir,
+    )
+
+    if not (cached_repo_data := get_cached_repo_data(proj_dirname=repo_name)):
+        raise ValueError("Failed to retrieve repo data from cache")
+
+    return {
+        "definition": cached_repo_data["build_definition"],
+        "repo": example_project_git_repo(),
+    }
+
+
+@pytest.fixture
+def repo_w_no_tags_conventional_commits(
     build_trunk_only_repo_w_no_tags: BuildSpecificRepoFn,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
     change_to_ex_proj_dir: None,
 ) -> BuiltRepoResult:
-    repo_name = repo_w_no_tags_angular_commits.__name__
+    repo_name = repo_w_no_tags_conventional_commits.__name__
     commit_type: CommitConvention = repo_name.split("_")[-2]  # type: ignore[assignment]
 
     return {
